#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 say
version:              0.1.0.1
visibility:           public
id:                   say-0.1.0.1-IrkjmAOSetTBCKONdL3OYI
key:                  say-0.1.0.1-IrkjmAOSetTBCKONdL3OYI
license:              MIT
copyright:            2016-2018 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/say#readme
synopsis:             Send textual messages to a Handle in a thread-friendly way
description:
    Please see the README and documentation at <https://www.stackage.org/package/say>

category:             Text
abi:                  2d12ffa95b5dee5007a56c067079fda1
exposed:              True
exposed-modules:      Say
hidden-modules:       Paths_say
import-dirs:          /usr/lib/ghc-9.6.6/site-local/say-0.1.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/say-0.1.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/say-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-say
hs-libraries:         HSsay-0.1.0.1-IrkjmAOSetTBCKONdL3OYI
depends:
    base-4.18.2.1 bytestring-0.11.5.3 text-2.0.2 transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-say/html/say.haddock
haddock-html:         /usr/share/doc/haskell-say/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

